@@ -1,31 +1,12 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
-# main.py file is part of subtrs.
-
-# Copyright 2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
-# All rights reserved.
-
-# subtrs is a simple tool that translates video subtitles
-
-# https://gitlab.com/dslackw/subtrs
-
-# subtrs is free software: you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
-
 
 import sys
 import os.path
 import googletrans
 from progress.bar import Bar
+from subtrs.cli import usage
 from colored import fore, style
 from googletrans import Translator
 from subtrs.__metadata__ import __prog__, __version__
@@ -39,8 +20,8 @@ class Subtitles:
         self.flags = flags
         self.file = args[0]
         self.dest = args[1].split(',')
-        self.ext = self.file[-4:]
-        self.f = ''
+        self.suffix = self.file[-4:]
+        self.subs_file = ''
         self.color()
         self.translator = Translator()
 
@@ -61,35 +42,52 @@ class Subtitles:
         '''Read the subtitle file'''
         try:
             with open(self.file, 'r', encoding='utf-8') as subs:
-                self.f = subs.readlines()
+                self.subs_file = subs.readlines()
         except IOError:
             print(f'The file "{self.file}" does not exist')
             sys.exit(1)
 
     def write_new_subs(self):
         '''Write the new subtitle file'''
-        for lang in self.dest:
+        for index, lang in enumerate(self.dest, 1):
             self.Exceptions_dest_lang(lang)
             self.read_subs()
             cap_file = self.file.split('/')[-1]
-            new_captions = f'{cap_file[:-4]}_{lang}{self.ext}'
+            new_captions = f'{cap_file[:-4]}_{lang}{self.suffix}'
+            self.trs_jobs(index, cap_file, lang)
             with open(new_captions, 'w') as new_subs:
-                bar = Bar('Processing', max=len(self.f))
-                for line in self.f:
+                bar = Bar('Processing', max=len(self.subs_file),
+                          suffix='%(percent)d%% - %(eta)ds')
+                for line in self.subs_file:
                     if line and not line[0].isdigit():
                         if len(line) > 1 and '--progress' not in self.flags:
-                            print(f'[{self.detect_lang(line)}]{self.IN_COLOR}'
-                                  f' <<{self.RESET_COLOR} {line}')
+                            self.print_line_in(line)
                         line = self.translate(line, lang)
                         if len(line) > 1 and '--progress' not in self.flags:
-                            print(f'[{lang}]{self.OUT_COLOR} >> '
-                                  f'{self.TRS_COLOR}{line}{self.RESET_COLOR}')
+                            self.print_line_out(line, lang)
                     new_subs.write(line)
                     if '--progress' in self.flags:
                         bar.next()
                 bar.finish()
             self.created_file(new_captions)
 
+    def trs_jobs(self, index, file, lang):
+        '''Printing the current job'''
+        print(f"[{index}/{len(self.dest)}] Subtitles "
+              f"'{file}' translate to {googletrans.LANGUAGES.get(lang)}")
+        if '--progress' not in self.flags:
+            print()
+
+    def print_line_in(self, line):
+        '''Print line before translated'''
+        print(f'[{self.detect_lang(line)}]{self.IN_COLOR}'
+              f' <<{self.RESET_COLOR} {line}')
+
+    def print_line_out(self, line, lang):
+        '''Print line after traslate'''
+        print(f'[{lang}]{self.OUT_COLOR} >> '
+              f'{self.TRS_COLOR}{line}{self.RESET_COLOR}')
+
     def translate(self, line, lang):
         '''Translate line per line'''
         return self.translator.translate(line, dest=lang).text + '\n'
@@ -101,9 +99,9 @@ class Subtitles:
     def created_file(self, file):
         '''Message when the file finished'''
         if self.file_exist(file):
-            print(f'The file "{file}" created.')
+            print(f"Subtitle file '{file}' created.")
         else:
-            print(f'The file "{file}" does not exist.')
+            print(f"Subtitle file '{file}' does not exist.")
 
     def file_exist(self, file):
         '''Check if the file exists'''
@@ -114,28 +112,10 @@ class Subtitles:
         try:
             self.translator.translate('Video', dest=lang).text
         except ValueError as Err:
-            print(f'Error: {Err} "{lang}"')
+            print(f"Error: {Err} '{lang}'")
             sys.exit(1)
 
 
-def usage(status):
-    '''CLI help menu'''
-    args = ['Usage: subtrs [subtitles_file] [destination languages]\n',
-            '       Simple tool that trlanslates video subtitles\n',
-            '       Support subtitles files [*.sbv, *.vtt, *.srt]',
-            '       Destination languages [en,de,ru] etc.\n',
-            'Optional arguments:',
-            '       --color      View translate text language with colour.',
-            '       --progress   Show progress bar.',
-            '  -l,  --languages  Show all supported languages.',
-            '  -v,  --version    Print the version and exit.',
-            '  -h,  --help       Show this message and exit.',
-            ]
-    for opt in args:
-        print(opt)
-    sys.exit(status)
-
-
 def args_flags(args):
     '''Manage flags'''
     flags = []
@@ -145,6 +125,8 @@ def args_flags(args):
     if '--progress' in args:
         args.remove('--progress')
         flags.append('--progress')
+    if len(flags) >= 2:
+        usage(1)
     return flags
 
 
@@ -153,7 +135,7 @@ def check_usage(args):
     file_ext = ['.sbv', '.vtt', '.srt']
 
     if args == []:
-        usage(status=0)
+        usage(status=1)
 
     # Show the version and exit
     if args[0] == '--version' or args[0] == '-v' and len(args) == 1:
